import os
import time

import dbus
import gconf

CONF_PATH = '/system/networking/connections'
USER_SETTINGS = 'org.freedesktop.NetworkManagerUserSettings'
SETTINGS = 'org.freedesktop.NetworkManagerSettings'
SETTINGS_OBJ = '/org/freedesktop/NetworkManagerSettings'

class NMPPPDDialer:

    def __init__(self):
        self.client = gconf.client_get_default()
        self.bus = dbus.SystemBus()
        self.obj = self.bus.get_object(USER_SETTINGS, SETTINGS_OBJ)
        self.int = dbus.Interface(self.obj, SETTINGS)
        self.int.connect_to_signal("NewConnection", self.new_connection_cb)
        self.conn = ""

    def configure(self, config, device):
        index = self._generate_config(config)

    def new_connection_cb(self, conn):
        print "NEW CONNECTION CO", conn
        self.conn = conn
        self.device = "/org/freedesktop/Hal/devices/usb_device_12d1_1003_noserial_if0_serial_usb_0"
        self.connect()

    def connect(self):
        obj = self.bus.get_object('org.freedesktop.NetworkManager',
                                  '/org/freedesktop/NetworkManager')
        self.int2 = dbus.Interface(obj, 'org.freedesktop.NetworkManager')
        print self.int2.ActivateConnection(USER_SETTINGS,
                                     self.conn,
                                     self.device,
                                     "/")

    def disconnect(self):
        pass

    def _generate_config(self, config):
        index = str(self._get_last_config_index() + 1)
        conf_dir = os.path.join(CONF_PATH, index)
        print "PATH", conf_dir
        self.client.add_dir(conf_dir, gconf.CLIENT_PRELOAD_NONE)
        for path in ['gsm', 'ppp', 'serial', 'connection']:
            _dir = os.path.join(conf_dir, path)
            self.client.add_dir(_dir, gconf.CLIENT_PRELOAD_NONE)

        opts = []
        # gsm
        opts.append(('gsm/band', 0))
        opts.append(('gsm/username', config.username))
        opts.append(('gsm/network-type', 0))
        opts.append(('gsm/number', "*99#"))
        opts.append(('gsm/apn', config.apn_host))
        opts.append(('gsm/name', 'gsm'))
        # ppp
        opts.append(('ppp/name', 'ppp'))
        # serial
        opts.append(('serial/baud', 115200))
        opts.append(('serial/name', 'serial'))
        # connection
        opts.append(('connection/id', 'Generated by Wader'))
        opts.append(('connection/timestamp', time.time()))
        opts.append(('connection/type', 'gsm'))
        opts.append(('connection/name', 'connection'))

        for name, value in opts:
            path = os.path.join(conf_dir, name)
            print "WRITING TO", path
            if isinstance(value, basestring):
                self.client.set_string(path, value)
            elif isinstance(value, int):
                self.client.set_int(path, value)
            elif isinstance(value, float):
                self.client.set_float(path, value)

        return index

    def _get_last_config_index(self):
        all_dirs = list(self.client.all_dirs(CONF_PATH))
        if not all_dirs:
            return 0

        #natsort(all_dirs)
        last = all_dirs[-1]
        return int(last.split('/')[-1])


if __name__ == '__main__':
    class Config(object):
        def __init__(self):
            self.username = "vodafone"
            self.password = "vodafone"
            self.apn_host = "ac.vodafone.es"

    import dbus.mainloop.glib
    import gobject
    loop = dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)

    conf = Config()
    dial = NMPPPDDialer()
    dial.configure(conf, None)

    loop = gobject.MainLoop()
    loop.run()
