# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
All the exceptions in WaderCdfL
"""


import dbus

CTS_ERROR = 'es.warp.Wader.Error.Contacts'
NET_ERROR = 'es.warp.Wader.Error.Network'
PIN_ERROR = 'es.warp.Wader.Error.PIN'
SMS_ERROR = 'es.warp.Wader.Error.SMS'
GEN_ERROR = 'es.warp.Wader.Error'

class AlreadyConnected(dbus.DBusException):
    """
    Raised when the user tries to connect to Internet and is already connected
    """
    _dbus_error_name = GEN_ERROR

class AlreadyConnecting(dbus.DBusException):
    """
    Raised when the user tries to connect to Internet and is in the middle of
    the process of connecting
    """
    _dbus_error_name = GEN_ERROR

class AlreadyTrackingError(dbus.DBusException):
    """
    Raised when the tracker is initialized twice
    """
    _dbus_error_name = GEN_ERROR

class NotTrackingError(dbus.DBusException):
    """
    Raised when something is trying to request data from a tracker
    """
    _dbus_error_name = GEN_ERROR

class ATError(dbus.DBusException):
    """Exception raised when an ERROR has occurred"""
    _dbus_error_name = GEN_ERROR

class ATTimeout(dbus.DBusException):
    """
    Exception raised when the timeout specified for the given C{ATCmd} expired
    """
    _dbus_error_name = GEN_ERROR

class AuthCancelled(dbus.DBusException):
    """Exception raised when user cancels the authentication"""
    _dbus_error_name = PIN_ERROR

class CharsetError(dbus.DBusException):
    """
    Exception raised when Wader can't find an appropriate charset at startup
    """
    _dbus_error_name = GEN_ERROR

class CMEErrorIncorrectPassword(dbus.DBusException):
    """Exception raised with a +CME ERROR: incorrect password"""
    _dbus_error_name = PIN_ERROR

class CMEErrorInvalidCharactersInDialString(dbus.DBusException):
    """
    Exception raised with a +CME ERROR: invalid characters in dial string
    """
    _dbus_error_name = CTS_ERROR

class CMEErrorNoNetworkService(dbus.DBusException):
    """
    Exception raised with a +CME ERROR: no network service
    """
    _dbus_error_name = NET_ERROR

class CMEErrorNotFound(dbus.DBusException):
    """Exception raised with a +CME ERROR: not found"""
    _dbus_error_name = SMS_ERROR

class CMEErrorOperationNotAllowed(dbus.DBusException):
    """Exception raised with a +CME ERROR: operation not allowed"""

class CMEErrorStringTooLong(dbus.DBusException):
    """Exception raised with a +CME ERROR: string too long"""
    _dbus_error_name = CTS_ERROR

class CMEErrorSIMBusy(dbus.DBusException):
    """Exception raised with a +CME ERROR: SIM busy"""
    _dbus_error_name = GEN_ERROR

class CMEErrorSIMFailure(dbus.DBusException):
    """Exception raised with a +CME ERROR: SIM failure"""
    _dbus_error_name = GEN_ERROR

class CMEErrorSIMNotStarted(dbus.DBusException):
    """Exception raised with +CME ERROR: SIM interface not started"""
    _dbus_error_name = GEN_ERROR

class CMEErrorSIMNotInserted(dbus.DBusException):
    """Exception raised with +CME ERROR: SIM not inserted"""
    _dbus_error_name = GEN_ERROR

class CMEErrorSIMPINRequired(dbus.DBusException):
    """Exception raised with +CME ERROR: SIM PIN required"""
    _dbus_error_name = PIN_ERROR

class CMEErrorSIMPUKRequired(dbus.DBusException):
    """Exception raised with +CME ERROR: SIM PUK required"""
    _dbus_error_name = PIN_ERROR

class CMEErrorSIMPUK2Required(dbus.DBusException):
    """Exception raised with +CME ERROR: SIM PUK2 required"""
    _dbus_error_name = PIN_ERROR

class CMSError300(dbus.DBusException):
    """CMS ERROR: Phone failure"""
    _dbus_error_name = SMS_ERROR

class CMSError301(dbus.DBusException):
    """CMS ERROR: SMS service of phone reserved """
    _dbus_error_name = SMS_ERROR

class CMSError302(dbus.DBusException):
    """CMS ERROR: Operation not allowed"""
    _dbus_error_name = SMS_ERROR

class CMSError303(dbus.DBusException):
    """CMS ERROR: Operation not supported"""
    _dbus_error_name = SMS_ERROR

class CMSError304(dbus.DBusException):
    """CMS ERROR: Invalid PDU mode parameter"""
    _dbus_error_name = SMS_ERROR

class CMSError305(dbus.DBusException):
    """CMS ERROR: Invalid text mode parameter"""
    _dbus_error_name = SMS_ERROR

class CMSError310(dbus.DBusException):
    """CMS ERROR: SIM not inserted"""
    _dbus_error_name = SMS_ERROR

class CMSError311(dbus.DBusException):
    """CMS ERROR: SIM PIN necessary"""
    _dbus_error_name = SMS_ERROR

class CMSError313(dbus.DBusException):
    """CMS ERROR: SIM failure"""
    _dbus_error_name = SMS_ERROR

class CMSError314(dbus.DBusException):
    """CMS ERROR: SIM busy"""
    _dbus_error_name = SMS_ERROR

class CMSError315(dbus.DBusException):
    """CMS ERROR: SIM wrong"""
    _dbus_error_name = SMS_ERROR

class CMSError320(dbus.DBusException):
    """CMS ERROR: Memory failure"""
    _dbus_error_name = SMS_ERROR

class CMSError321(dbus.DBusException):
    """CMS ERROR: Invalid memory index"""
    _dbus_error_name = SMS_ERROR

class CMSError322(dbus.DBusException):
    """CMS ERROR: Memory full"""
    _dbus_error_name = SMS_ERROR

class CMSError330(dbus.DBusException):
    """CMS ERROR: SMSC address unknown"""
    _dbus_error_name = SMS_ERROR

class CMSError331(dbus.DBusException):
    """CMS ERROR: No network service"""
    _dbus_error_name = SMS_ERROR

class CMSError332(dbus.DBusException):
    """CMS ERROR: Network timeout"""
    _dbus_error_name = SMS_ERROR

class CMSError500(dbus.DBusException):
    """CMS ERROR: Unknown Error"""
    _dbus_error_name = SMS_ERROR

class DeviceAlreadyAddedError(dbus.DBusException):
    """The device is already handled by the system"""
    _dbus_error_name = GEN_ERROR

class DeviceConfigurationError(dbus.DBusException):
    """Exception raised an error occured while configuring a device"""
    _dbus_error_name = GEN_ERROR

class DeviceNotFoundError(dbus.DBusException):
    """Exception raised when no suitable device has been found"""
    _dbus_error_name = GEN_ERROR

class DeviceLacksExtractInfo(dbus.DBusException):
    """
    Exception raised when no control ports nor data ports have been extracted
    """
    _dbus_error_name = GEN_ERROR

class DeviceLockedError(dbus.DBusException):
    """
    Exception raised after an authentication mess ending up in a device locked
    """
    _dbus_error_name = PIN_ERROR

class IllegalOperationError(dbus.DBusException):
    """
    Raised on single port devices that try to execute command while connected
    """
    _dbus_error_name = GEN_ERROR

class LimitedServiceNetworkError(dbus.DBusException):
    """
    Exception raised when AT+COPS? replied "Limited Service"
    """
    _dbus_error_name = NET_ERROR

class InputValueError(dbus.DBusException):
    """Exception raised when INPUT VALUE IS OUT OF RANGE is received"""

class MalformedSMSError(dbus.DBusException):
    """Exception raised when an error is received decodifying a SMS"""
    _dbus_error_name = SMS_ERROR

class NetworkRegistrationError(dbus.DBusException):
    """
    Exception raised when an error occurred while registering with the network
    """
    _dbus_error_name = NET_ERROR

class NetworkTemporalyUnavailableError(dbus.DBusException):
    """
    Exception raised when the network we are registered with its not available
    """
    _dbus_error_name = NET_ERROR

class NotConnectedError(dbus.DBusException):
    """Exception raised when we are not connected and try to disconnect"""
    _dbus_error_name = GEN_ERROR

class OSNotRegisteredError(dbus.DBusException):
    """Exception raised when the current OS is not registered"""
    _dbus_error_name = GEN_ERROR

class ProfileNotFoundError(dbus.DBusException):
    """Exception raised when a profile hasn't been found"""
    _dbus_error_name = GEN_ERROR

class ProfileInUseError(dbus.DBusException):
    """Exception raised when user tries to delete the active profile"""
    _dbus_error_name = GEN_ERROR

class StateMachineNotReadyError(dbus.DBusException):
    """
    Raised when a third-party developer tries to obtain a reference to the
    state machine too soon
    """
    _dbus_error_name = GEN_ERROR

class UnknownPluginNameError(dbus.DBusException):
    """
    Exception raised when we don't have a plugin with the given remote name
    """
    _dbus_error_name = GEN_ERROR

class InvalidUDIError(dbus.DBusException):
    """
    Exception raised when the supplied UDI was bogus
    """
    _dbus_error_name = GEN_ERROR
