# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
The hardware module manages device discovery via dbus/hal
"""
import os

from wader.common.hardware._dbus import DBusComponent, DBusExporterHelper

def dict_reverter(dict_in):
    """Returns a reverted copy of C{dict_in}"""
    dict_out = {}
    for k, v in dict_in.iteritems():
        dict_out[v] = k

    return dict_out

def _get_hardware_manager():
    if os.name == 'posix':
        from wader.common.hardware._unixhardwaremanager import HardwareManager
    elif os.name == 'nt':
        from wader.common.hardware._winhardwaremanager import HardwareManager

    return HardwareManager

HardwareManager = _get_hardware_manager()

CONN_OPTS = {
    0 : '2GONLY',
    1 : '3GONLY',
    2 : '2GPREF',
    3 : '3GPREF',
    4 : 'ANY',
}

BAND_OPTS = {
    0 : 'EGSM',  # EGSM (900MHz)
    1 : 'DCS',   # DCS (1800MHz)
    2 : 'PCS',   # PCS (1900MHz)
    3 : 'G850',  # GSM  (850MHz)
    4 : 'U2100', # WCDMA  2100MHz           (Class I)
    5 : 'U1700', # WCDMA 3GPP UMTS1800      (Class III)
    6 : 'U17IV', # WCDMA 3GPP AWS 1700/2100 (Class IV)
    7 : 'U850',  # WCDMA 3GPP UMTS850       (Class V)
    8 : 'U800',  # WCDMA 3GPP UMTS800       (Class VI)
    9 : 'U900',  # WCDMA 3GPP UMTS900       (Class VIII)
   10 : 'U17IX', # WCDMA 3GPP UMTS          (Class IX)
   11 : 'ANY',   # ANY
}

CONN_OPTS_REV = dict_reverter(CONN_OPTS)
BAND_OPTS_REV = dict_reverter(BAND_OPTS)


__all__ = ["DBusComponent", "DBusExporterHelper", "HardwareManager",
           "CONN_OPTS", "BAND_OPTS", "CONN_OPTS_REV", "BAND_OPTS_REV"]
