# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""dbus stuff"""

import dbus

class DBusComponent(object):
    """I provide a couple of useful methods to deal with DBus"""

    def __init__(self):
        self.bus = dbus.SystemBus()
        self.obj = self.bus.get_object('org.freedesktop.Hal',
                                  '/org/freedesktop/Hal/Manager')
        self.manager = dbus.Interface(self.obj, 'org.freedesktop.Hal.Manager')

    def get_properties_from_udi(self, udi):
        """Returns all the properties from C{udi}"""
        obj = self.bus.get_object('org.freedesktop.Hal', udi)
        dev = dbus.Interface(obj, 'org.freedesktop.Hal.Device')
        return dev.GetAllProperties()

    def get_devices_properties(self):
        """Returns all the properties from all devices registed in HAL"""
        props = {}
        for udi in self.manager.GetAllDevices():
            props[udi] = self.get_properties_from_udi(udi)
        return props


class DBusExporterHelper(object):
    """
    I am a helper for classes that export methods over DBus
    """
    def __init__(self):
        super(DBusExporterHelper, self).__init__()

    def add_generic_callbacks(self, deferred, async_cb, async_eb):
        """
        Adds C{async_cb} and C{async_eb} to C{deferred}
        """
        deferred.addCallback(async_cb)
        deferred.addErrback(self.process_failure, async_eb)
        return deferred

    def add_generic_callbacks_and_swallow(self, deferred, async_cb, async_eb):
        """
        Adds C{async_cb} n C{async_eb} to C{deferred} and swallows the result

        This method is useful for functions that might return some garbage,
        but we are not interested in the result
        """
        deferred.addCallback(lambda _: async_cb())
        deferred.addErrback(self.process_failure, async_eb)
        return deferred

    def process_failure(self, failure, async_eb):
        """
        Extracts the exception wrapped in C{failure} and calls C{async_eb}
        """
        # possible since python-dbus 0.82.3 (fd.o #12403)
        async_eb(failure.type(failure.value))

