# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
Common stuff for all SierraWireless cards
"""

import re

from wader.common.plugin import DBusDevicePlugin
from wader.common.command import get_cmd_dict_copy, OK_REGEXP, ERROR_REGEXP
from wader.common.hardware.base import WCDMACustomizer

SIERRA_CONN_DICT = {
    'ANY'    : 'AT!SELRAT=00',
    '3GONLY' : 'AT!SELRAT=01',
    '2GONLY' : 'AT!SELRAT=02',
    '3GPREF' : 'AT!SELRAT=03',
    '2GPREF' : 'AT!SELRAT=04',
}

SIERRA_BAND_DICT = {
    'ANY'   : 'AT!BAND=00',   # any band
    'EGSM'  : 'AT!BAND=03',   # EGSM (900MHz)
    'DCS'   : 'AT!BAND=03',   # DCS (1800MHz)
    'PCS'   : 'AT!BAND=04',   # PCS (1900MHz)
    'G850'  : 'AT!BAND=04',   # GSM (850 MHz)
    'U2100' : 'AT!BAND=02',   # WCDMA 2100Mhz         (Class I)
    'U800'  : 'AT!BAND=02',   # WCDMA 3GPP UMTS800   (Class VI)
}


info = dict(echo=None,
            end=OK_REGEXP,
            error=ERROR_REGEXP,
            extract=re.compile(r"""
                \r\n
                \+CREG:\s
                (?P<mode>\d),(?P<status>\d+)(,[0-9a-fA-F]*,[0-9a-fA-F]*)?
                \r\n
                """, re.VERBOSE))

SIERRA_CMD_DICT = get_cmd_dict_copy()
SIERRA_CMD_DICT['get_netreg_status'] = info

class SierraWirelessWCDMACustomizer(WCDMACustomizer):
    async_regexp = None
    band_dict = SIERRA_BAND_DICT
    conn_dict = SIERRA_CONN_DICT
    cmd_dict = SIERRA_CMD_DICT


class SierraWCDMADevicePlugin(DBusDevicePlugin):
    custom = SierraWirelessWCDMACustomizer()

