# -*- coding: utf-8 -*-
# Copyright (C) 2006-2007  Vodafone España, S.A.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
Common stuff for all zte's cards
"""

import re

from wader.common.command import get_cmd_dict_copy, OK_REGEXP, ERROR_REGEXP
from wader.common.plugin import DBusDevicePlugin
from wader.common.hardware.base import WCDMACustomizer

ZTE_CONN_DICT = {
    'ANY'    : 'AT^ZSNT=0,0,0',
    '2GONLY' : 'AT^ZSNT=1,0,0',
    '3GONLY' : 'AT^ZSNT=2,0,0',
    '2GPREF' : 'AT^ZSNT=0,0,1',
    '3GPREF' : 'AT^ZSNT=1,0,2',
}

ZTE_BAND_DICT = {
    'ANY'   : 'at+zbandi=0',   # any band
    'EGSM'  : 'EGSM,1',  # EGSM (900MHz)
    'DCS'   : 'DCS,1',   # DCS (1800MHz)
    'PCS'   : 'at+zbandi=4',   # PCS (1900MHz)
    'G850'  : 'at+zbandi=3',  # GSM (850 MHz)
    'U2100' : 'at+zbandi=2', # WCDMA 2100Mhz            (Class I)
    'U1700' : 'U1700,1', # WCDMA 3GPP UMTS1800      (Class III)
    'U17IV' : 'U17IV,1', # WCDMA 3GPP AWS 1700/2100 (Class IV)
    'U850'  : 'at+zbandi=1',  # WCDMA 3GPP UMTS850       (Class V)
    'U800'  : 'U800,1',  # WCDMA 3GPP UMTS800       (Class VI)
    'U900'  : 'U900,1',  # WCDMA 3GPP UMTS900       (Class VIII)
    'U17IX' : 'U17IX,1', # WCDMA 3GPP UMTS          (Class IX)
}


ZTE_CMD_DICT = get_cmd_dict_copy()

info = dict(echo=None,
            end=OK_REGEXP,
            error=ERROR_REGEXP,
            extract=re.compile(r"""
                \r\n
                \+CREG:\s
                (?P<mode>\d),(?P<status>\d+)(,[0-9a-fA-F]*,[0-9a-fA-F]*)?
                \r\n
                """, re.VERBOSE))

ZTE_CMD_DICT['get_netreg_status'] = info

class ZTEWCDMACustomizer(WCDMACustomizer):
    async_regexp = None
    band_dict = ZTE_BAND_DICT
    conn_dict = ZTE_CONN_DICT
    cmd_dict = ZTE_CMD_DICT


class ZTEWCDMADevicePlugin(DBusDevicePlugin):
    custom = ZTEWCDMACustomizer()

