# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""Wader notifications"""



import dbus

from wader.common.consts import WADER_SERVICE, WADER_OBJPATH

# SIGNALS
SIG_CONNECTED = 'Connected'
SIG_DEVICE_ADDED = 'DeviceAdded'
SIG_DEVICE_REMOVED = 'DeviceRemoved'
SIG_DISCONNECTED = 'Disconnected'
SIG_INVALID_DNS = 'InvalidDNS'
SIG_NEW_CONN_MODE = 'CellTypeChanged'
SIG_CALL = 'CallReceived'
SIG_CREG = 'CregReceived'
SIG_RSSI = 'RSSIChanged'
SIG_SMS = 'SMSReceived'
SIG_SPEED = 'SpeedChanged'
SIG_TIMEOUT = 'Timeout'

NO_SIGNAL = 'NO_SIGNAL'
GPRS_SIGNAL = 'GPRS_SIGNAL'
UMTS_SIGNAL = 'UMTS_SIGNAL'
HSDPA_SIGNAL = 'HSDPA_SIGNAL'
HSUPA_SIGNAL = 'HSUPA_SIGNAL'
HSPA_SIGNAL = 'HSPA_SIGNAL'

THREEG_SIGNALS = [UMTS_SIGNAL, HSDPA_SIGNAL, HSUPA_SIGNAL, HSPA_SIGNAL]


class NotificationManager(object):
    """
    I take care of connecting notification callbacks to the corresp. signals
    """

    def __init__(self, noti_callbacks):
        super(NotificationManager, self).__init__()
        self.noti_callbacks = noti_callbacks
        self.signal_matchers = []
        self.bus = dbus.SessionBus()

    def connect_listeners(self):
        for signal, callback in self.noti_callbacks.iteritems():
            if not callback:
                continue

            self.signal_matchers.append(self.bus.add_signal_receiver(
                                        callback,
                                        signal,
                                        bus_name=WADER_SERVICE,
                                        path=WADER_OBJPATH))

    def remove_listeners(self):
        while self.signal_matchers:
            sm = self.signal_matchers.pop()
            sm.remove()

