# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
Linux-based OS plugin
"""

from os.path import join

from wader.common.oses.unix import UnixPlugin
from wader.utils.utilities import get_file_data, extract_lsb_info
from wader.common.runtime import app_is_frozen

if app_is_frozen():
    lsb_info = None
else:
    lsb_info = extract_lsb_info()


class LinuxPlugin(UnixPlugin):
    """
    OSPlugin for Linux-based distros
    """

    dialer = None

    def __init__(self):
        super(LinuxPlugin, self).__init__()

    def check_dialer_assumptions(self):
        return []

    def check_permissions(self):
        return []

    def get_connection_args(self, dialer):
        return []

    def get_disconnection_args(self, dialer):
        return []

    def get_iface_stats(self, iface='ppp0'):
        stats_path = "/sys/class/net/%s/statistics" % iface
        rx_b = join(stats_path, 'rx_bytes')
        tx_b = join(stats_path, 'tx_bytes')
        return map(int, [get_file_data(rx_b), get_file_data(tx_b)])

    def is_valid(self, os_info=lsb_info):
        if not os_info:
            # lsb_info will be None on any OS != Linux
            return False

        try:
            if self.os_name.match(os_info['os_name']):
                if self.os_version:
                    if self.os_version.search(os_info['os_version']):
                        return True
                    else:
                        # version doesn't match
                        return False
                else:
                    # No version specified
                    return True
            else:
                # distro name doesn't match
                return False
        except KeyError:
            return False

