# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
I manage the resources
"""


from wader.common.oal import osobj
from wader.common.daemon import WaderDaemonFactory
from wader.common.startup import attach_serial_protocol
from wader.common.notifications import NotificationManager

class ResourceManager(object):
    """
    I'm the entry point to access system resources at runtime
    """
    def __init__(self):
        super(ResourceManager, self).__init__()
        self.notimanager = None
        self.daemons = None
        self.device = None

    def setup_device(self, device):
        if device.sconn:
            self.device = device
            # device might be already configured by configuration dialog
            return device

        self.device = attach_serial_protocol(device)
        return self.device

    def setup_daemons(self, wrapper, device, noti_cbs):
        # get the daemon collection for this device
        self.daemons = WaderDaemonFactory.build_daemon_collection(device)
        self.notimanager = NotificationManager(noti_cbs)
        self.notimanager.connect_listeners()
        return self.daemons, self.notimanager

    def get_dialer(self):
        dialer = osobj.dialer
        if not dialer.sconn:
            dialer.sconn = self.device.sconn

        return dialer
