# -*- coding: utf-8 -*-
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

from datetime import datetime

from zope.interface import implements

from wader.common.interfaces import IMessage
from wader.contrib.pdu_sms.pdu import PDU

class Message(object):
    """
    I am a Message in the system
    """
    implements(IMessage)

    def __init__(self, number, text, index=None, where=None,
                 csca=None, _datetime=None):
        self.number = number
        self.text = text
        self.index = index
        self.where = where
        self.csca = csca
        self.datetime = _datetime
        self.ref = None
        self.cnt = None
        self.seq = None

    def __repr__(self):
        return "<Message  number: %s, text: %s>" % (self.number, self.text)

    def __eq__(self, m):
        if IMessage.providedBy(m):
            return self.number == m.number and self.text == m.text

        return False

    def __ne__(self, m):
        return not self.__eq__(m)

    def get_number(self):
        return self.number

    def get_text(self):
        return self.text

    def get_index(self):
        return self.index


def extract_datetime(datestr):
    """
    Returns a C{datetime} object out of C{datestr}
    """
    from twisted.python import log
    log.msg("datestr received %s" % datestr)
    #datestr comes like "YY/MM/DD HH:MM:SS"
    date, time = datestr.split(' ')
    year, month, day = map(int, date.split('/'))
    if year < 68:
        year += 2000
    hour, mins, seconds = map(int, time.split(':'))
    return datetime(year, month, day, hour, mins, seconds)

def pdu_to_message(pdu):
    """
    Converts C{pdu} to a C{Message} object
    """
    p = PDU()
    data = p.decode_pdu(pdu)
    sender, datestr, text, csca, ref, cnt, seq, fmt = data
    try:
        _datetime = extract_datetime(datestr)
    except ValueError:
        _datetime = datetime.now()

    m = Message(sender, text, _datetime=_datetime, csca=csca)
    m.ref, m.cnt, m.seq = ref, cnt, seq

    return m


def message_to_pdu(sms):
    """
    Converts C{sms} to its PDU representation
    """
    p = PDU()
    csca = ""
    if sms.csca:
        csca = sms.csca
    return p.encode_pdu(sms.number, sms.text, csca=csca)
