# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
Stuff used at startup
"""

import os
import shutil
import sys

from twisted.internet import reactor
from twisted.python import log

import wader

from wader.common.serialport import SerialPort
import wader.common.consts as consts
from wader.utils.utilities import save_file, get_file_data

DELAY = 10

LOCK = os.path.join(consts.WADER_HOME, '.setup-done')

def attach_serial_protocol(device, udi):
    """
    Returns C{device} with a reference to the protocol's instance
    """
    from wader.common.exported import WCDMAAdapter

    # Use the adapter that device specifies
    if device.custom.adapter:
        adapter_klass = device.custom.adapter
    else:
        adapter_klass = WCDMAAdapter

    log.msg("ADAPTING %s to %s" % (device, adapter_klass))
    sconn = adapter_klass(device, udi)

    port = device.has_two_ports() and device.cport or device.dport
    # keep a reference to the SerialPort, in case we need to stop it or
    # something
    device.sport = SerialPort(sconn, port, reactor, udi,
                              baudrate=device.baudrate)
    device.sconn = sconn
    return device


def create_skeleton_and_do_initial_setup():
    """I perform the operations needed for the initial user setup"""
    if os.path.exists(LOCK):
        version = get_file_data(LOCK)
        try:
            last_version = tuple(map(int, version.split('.')))
        except ValueError:
            return

        current_version = tuple(map(int, wader.version.short().split('.')))
        if current_version > last_version:
            # copy plugins to plugins dir
            # XXX: deleting any plugin that the user already had is not nice
            shutil.rmtree(consts.PLUGINS_HOME)
            shutil.copytree(consts.PLUGINS_DIR, consts.PLUGINS_HOME)

        return

    try:
        shutil.rmtree(consts.WADER_HOME, True)
        os.mkdir(consts.WADER_HOME)
        os.mkdir(consts.MOBILE_PROFILES)
    except OSError:
        log.err()

    # copy plugins to plugins dir
    shutil.copytree(consts.PLUGINS_DIR, consts.PLUGINS_HOME)

    join = os.path.join
    cfg_path = join(consts.TEMPLATES_DIR, 'wader.cfg.tpl')
    shutil.copy(cfg_path, consts.WADER_CFG)

    os.chmod(consts.WADER_CFG, 0600)
    populate_dbs()
    save_file(LOCK, wader.version.short())

def populate_dbs():
    """
    Populates the different databases
    """
    try:
        # only will succeed on development
        networks = __import__('resources/extra/networks')
    except ImportError:
        try:
            # this fails on feisty but not on gutsy
            networks = __import__(os.path.join(consts.EXTRA_DIR, 'networks'))
        except ImportError:
            sys.path.insert(0, consts.EXTRA_DIR)
            import networks

    instances = [getattr(networks, item)() for item in dir(networks)
            if (not item.startswith('__') and item != 'NetworkOperator')]
    from wader.common.persistent import net_manager
    net_manager.populate_networks(instances)

