# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
"""Misc utilities"""

import re
import types
import subprocess

def MixIn(pyClass, mixInClass, makeAncestor=0):
    """
    Mixes in C{mixInClass} in C{pyClass}
    """
    # extracted from http://www.linuxjournal.com/node/4540/print
    if makeAncestor:
        if mixInClass not in pyClass.__bases__:
            pyClass.__bases__ = (mixInClass,) + pyClass.__bases__
    else:
        # Recursively traverse the mix-in ancestor
        # classes in order to support inheritance
        baseClasses = list(mixInClass.__bases__)
        baseClasses.reverse()
        for baseClass in baseClasses:
            MixIn(pyClass, baseClass)
        # Install the mix-in methods into the class
        for name in dir(mixInClass):
            if not name.startswith('__'):
                # skip private members
                member = getattr(mixInClass, name)
                if type(member) is types.MethodType:
                    member = member.im_func
                setattr(pyClass, name, member)


def natsort(l):
    """
    Naturally sort list C{l} in place
    """
    # extracted from http://nedbatchelder.com/blog/200712.html#e20071211T054956
    convert = lambda text: int(text) if text.isdigit() else text
    alphanum_key = lambda key: [convert(c) for c in re.split('([0-9]+)', key)]
    l.sort(key=alphanum_key)


def run_lsb_cmd(cmd):
    def run_command(cmd):
        proc = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,)
        stdout_val = proc.communicate()[0]
        return stdout_val

    resp = run_command(cmd)
    val = resp.split('\t')[1]
    return val.replace('\n', '')

def extract_lsb_info():
    info = {}
    try:
        return dict(os_name=run_lsb_cmd('lsb_release -i'),
                    os_version=run_lsb_cmd('lsb_release -r'))

    except IndexError:
        return None

    return info

def get_file_data(path):
    """Returns the data of the file at path C{path}"""
    try:
        fileobj = open(path, 'r')
        data = fileobj.read()
        return data
    finally:
        fileobj.close()

def save_file(path, data):
    """saves C{data} in C{path}"""
    try:
        fileobj = open(path, 'w')
        fileobj.write(data)
    finally:
        fileobj.close()

def is_bogus_ip(ip):
    """Returns True if C{ip} is a bogus ip"""
    return ip in ["10.11.12.13", "10.11.12.14"]

number_pattern = re.compile('^\+?\d+$')

def is_valid_number(number):
    return number_pattern.match(number) and True or False

