# -*- coding: utf-8 -*-
# Copyright (C) 2006-2008  Vodafone España, S.A.
# Copyright (C) 2008  Warp Networks, S.L.
# Author:  Pablo Martí
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""
Starts Wader

execute it with:  twistd -r glib2 -oy core-tap.py
"""

import locale
import signal

from twisted.application.service import Application, IProcess
from twisted.application import strports

# i10n stuff
locale.setlocale(locale.LC_ALL, '')

from wader.common.startup import create_skeleton_and_do_initial_setup

# it will just return if its not necessary
create_skeleton_and_do_initial_setup()

# we delays this imports as they depend on modules that in turn depend on
# stuff that depend on plugins. If we dont delay this imports after the
# initial setup is complete we would get a circular import
from wader.cli.startup import CoreSerialService
from wader.common import shell
from wader.common.consts import APP_SLUG_NAME, APP_NAME, SSH_PORT, WADER_CFG
from wader.common.configbase import WaderConfigBase
from wader.common.encoding import _

# access osobj singleton
from wader.common.exceptions import OSNotRegisteredError
try:
    from wader.common.oal import osobj
except OSNotRegisteredError:
    message = _('OS/Distro not registered')
    details = """
The OS/Distro under which you are running %s
is not registered in the OS database. Check the common.oal module for what
you can do in order to support your OS/Distro
""" % APP_NAME
    raise SystemExit("%s\n%s" % (message, details))

from wader.common.shutdown import shutdown_core
signal.signal(signal.SIGINT, shutdown_core)

config = WaderConfigBase(WADER_CFG)

service = CoreSerialService()
application = Application(APP_NAME)

if config.getboolean('plugins', 'ssh_shell'):
    user = config.get('plugins', 'ssh_user')
    passwd = config.get('plugins', 'ssh_pass')
    factory = shell.getManholeFactory(globals(), admin=passwd)
    strports.service(SSH_PORT, factory).setServiceParent(application)

IProcess(application).processName = APP_SLUG_NAME
service.setServiceParent(application)
