# -*- coding: utf-8 -*-
# Author:  Jaime Soriano
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

from twisted.internet import defer

from wader.common.exported import WCDMAAdapter
from wader.common.hardware.huawei import (HuaweiWCDMADevicePlugin,
                                          HuaweiWCDMACustomizer)

class HuaweiE17XAdapter(WCDMAAdapter):
    def get_phonebook_size(self):
        # the E170 that we have around keeps raising ATErrors whenever
        # is asked for its size, we'll have to cheat till we have time
        # to find a workaround
        return defer.succeed(250)

    def get_contacts(self):
        # we return a list with all the contacts that match '', i.e. all
        return self.find_contacts('')


class HuaweiE17XCustomizer(HuaweiWCDMACustomizer):
    adapter = HuaweiE17XAdapter


class HuaweiE172(HuaweiWCDMADevicePlugin):
    """L{wader.common.plugin.DBusDevicePlugin} for Huawei's E172"""
    name = "Huawei E172"
    version = "0.1"
    author = u"Jaime Soriano"
    custom = HuaweiE17XCustomizer()

    __remote_name__ = "E17X"

    __properties__ = {
        'usb_device.vendor_id' : [0x12d1],
        'usb_device.product_id' : [0x1003],
    }
